@@ -4,7 +4,7 @@
 
     gerbera-autoscan.module.js - this file is part of Gerbera.
 
-    Copyright (C) 2016-2022 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -20,9 +20,9 @@
 
     $Id$
 */
-import {GerberaApp} from './gerbera-app.module.js';
-import {Auth} from './gerbera-auth.module.js';
-import {Updates} from './gerbera-updates.module.js';
+import { GerberaApp } from './gerbera-app.module.js';
+import { Auth } from './gerbera-auth.module.js';
+import { Updates } from './gerbera-updates.module.js';
 
 const initialize = () => {
   $('#autoscanModal').autoscanmodal('reset');
@@ -37,6 +37,10 @@ const addAutoscan = (event) => {
       object_id: item.id,
       action: 'as_edit_load',
       audio: item.audio,
+      retryCount: item.retryCount,
+      interval: item.interval,
+      dirTypes: item.dirTypes,
+      forceRescan: item.forceRescan,
       audioMusic: item.audioMusic,
       audioBook: item.audioBook,
       audioBroadcast: item.audioBroadcast,
@@ -46,12 +50,15 @@ const addAutoscan = (event) => {
       videoMovie: item.videoMovie,
       videoTV: item.videoTV,
       videoMusicVideo: item.videoMusicVideo,
-      from_fs: fromFs
+      ctAudio: item.ctAudio,
+      ctImage: item.ctImage,
+      ctVideo: item.ctVideo,
+      from_fs: fromFs,
     };
     requestData[Auth.SID] = Auth.getSessionId();
 
     if (GerberaApp.getType() === 'db') {
-      requestData = $.extend({}, requestData, {updates: 'check'});
+      requestData = $.extend({}, requestData, { updates: 'check' });
     }
 
     $.ajax({
@@ -69,7 +76,13 @@ const addAutoscan = (event) => {
 const loadNewAutoscan = (response) => {
   const autoscanModal = $('#autoscanModal');
   if (response.success) {
-    autoscanModal.autoscanmodal('loadItem', {item: response.autoscan, onSave: submitAutoscan});
+    autoscanModal.autoscanmodal('loadItem', {
+      inotify: GerberaApp.serverConfig['have-inotify'],
+      item: response.autoscan,
+      onSave: submitAutoscan,
+      onDetails: showDetails,
+      onHide: hideDetails
+    });
     autoscanModal.autoscanmodal('show');
     Updates.updateTreeByIds(response);
   }
@@ -92,12 +105,51 @@ const submitAutoscan = () => {
       data: requestData
     }).then((response) => {
       submitComplete(response);
+      if (item.scan_mode === 'manual') {
+          runScan({ data: item });
+      }
     }).catch((err) => {
       GerberaApp.error(err);
     });
   }
 };
 
+const runScan = (event) => {
+  const item = event.data;
+  if (item) {
+    const fromFs = GerberaApp.getType() === 'fs';
+    const request = {
+      req_type: 'autoscan',
+      object_id: item.id,
+      action: 'as_run',
+      from_fs: fromFs,
+    }
+    request[Auth.SID] = Auth.getSessionId();
+    let requestData = $.extend({}, request, item);
+    if (GerberaApp.getType() === 'db') {
+      requestData = $.extend({}, requestData, { updates: 'check' });
+    }
+
+    $.ajax({
+      url: GerberaApp.clientConfig.api,
+      type: 'get',
+      data: requestData
+    }).then((response) => {
+      submitComplete(response);
+    }).catch((err) => {
+      GerberaApp.error(err);
+    });
+  }
+};
+
+const showDetails = () => {
+  $('#autoscanModal').editmodal('showDetails');
+};
+
+const hideDetails = () => {
+  $('#autoscanModal').editmodal('hideDetails');
+};
+
 const submitComplete = (response) => {
   let msg;
   if (response.success) {
@@ -115,6 +167,7 @@ const submitComplete = (response) => {
 
 export const Autoscan = {
   addAutoscan,
+  runScan,
   initialize,
   loadNewAutoscan,
   submitAutoscan,
